transmissivity
--------------

.. inheritance-diagram:: climlab.radiation.transmissivity
   :parts: 1
   :private-bases:

.. automodule:: climlab.radiation.transmissivity
    :members:
    :undoc-members: 
    :show-inheritance: